package com.ruoyi.project.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.plant.mapper.TTargetactionMapper;
import com.ruoyi.project.plant.domain.TTargetaction;
import com.ruoyi.project.plant.service.ITTargetactionService;

import javax.annotation.Resource;

/**
 * 目标回顾行动项Service业务层处理
 *
 * @author ruoyi
 * @date 2021-08-16
 */
@Service
public class TTargetactionServiceImpl implements ITTargetactionService
{
    @Resource
    private TTargetactionMapper tTargetactionMapper;

    /**
     * 查询目标回顾行动项
     *
     * @param id 目标回顾行动项ID
     * @return 目标回顾行动项
     */
    @Override
    public TTargetaction selectTTargetactionById(Long id)
    {
        return tTargetactionMapper.selectTTargetactionById(id);
    }

    /**
     * 查询目标回顾行动项列表
     *
     * @param tTargetaction 目标回顾行动项
     * @return 目标回顾行动项
     */
    @Override
    public List<TTargetaction> selectTTargetactionList(TTargetaction tTargetaction)
    {
        return tTargetactionMapper.selectTTargetactionList(tTargetaction);
    }

    /**
     * 新增目标回顾行动项
     *
     * @param tTargetaction 目标回顾行动项
     * @return 结果
     */
    @Override
    public int insertTTargetaction(TTargetaction tTargetaction)
    {
        return tTargetactionMapper.insertTTargetaction(tTargetaction);
    }

    /**
     * 修改目标回顾行动项
     *
     * @param tTargetaction 目标回顾行动项
     * @return 结果
     */
    @Override
    public int updateTTargetaction(TTargetaction tTargetaction)
    {
        return tTargetactionMapper.updateTTargetaction(tTargetaction);
    }

    /**
     * 批量删除目标回顾行动项
     *
     * @param ids 需要删除的目标回顾行动项ID
     * @return 结果
     */
    @Override
    public int deleteTTargetactionByIds(Long[] ids)
    {
        return tTargetactionMapper.deleteTTargetactionByIds(ids);
    }

    /**
     * 删除目标回顾行动项信息
     *
     * @param id 目标回顾行动项ID
     * @return 结果
     */
    @Override
    public int deleteTTargetactionById(Long id)
    {
        return tTargetactionMapper.deleteTTargetactionById(id);
    }
}
